==> kbear-1.1.tar.gz: kbear-1.1/kbear/kbeartransferview.h <==
/***************************************************************************
                          kbeartransferview.h  -  description
                             -------------------
    begin                : Wed Jun 28 2000
    copyright            : (C) 2000 by Bjrn Sahlstrm
    email                : bjorn.sahlstrom@mail.bip.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBEARTRANSFERVIEW_H
#define KBEARTRANSFERVIEW_H

//////////////////////////////////////////////////////////////////////
// Qt include files
#include <qwidget.h>
#include <qwhatsthis.h>
#include <qpopupmenu.h>
//////////////////////////////////////////////////////////////////////
// KDE include files
#include <klocale.h>
#include <kapp.h>
//////////////////////////////////////////////////////////////////////
// Application specific include files
#include "kbeartreeview.h"
#include "kbeartransferviewitem.h"

class KBearTransferViewItem;

/**
	*This class represent the transfer view
  *@author Bjrn Sahlstrm
  */
class KBearTransferView : public KBearTreeView {
   Q_OBJECT

public:
	/**  */
	KBearTransferView(QWidget *parent=0, const char *name=0 );
	/**  */
	~KBearTransferView();
signals: // Signals
	/**  */
	void showMenu( KBearTreeViewItem* );
protected slots: // Protected slots
	/**  */
	void slotItemRightPressed( KListView*, QListViewItem*, const QPoint& );
};

#endif

==> kbear_1.2.1.orig.tar.gz: kbear-1.2.1/kbear/kbeartransferview.h <==
/***************************************************************************
                          kbeartransferview.h  -  description
                             -------------------
    begin                : Wed Jun 28 2000
    copyright            : (C) 2000 by Bjrn Sahlstrm
    email                : bjorn.sahlstrom@mail.bip.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBEARTRANSFERVIEW_H
#define KBEARTRANSFERVIEW_H

//////////////////////////////////////////////////////////////////////
// Qt include files
#include <qwidget.h>
#include <qwhatsthis.h>
#include <qpopupmenu.h>
//////////////////////////////////////////////////////////////////////
// KDE include files
#include <klocale.h>
#include <kapp.h>
//////////////////////////////////////////////////////////////////////
// Application specific include files
#include "kbeartreeview.h"
#include "kbeartransferviewitem.h"

class KBearTransferViewItem;

/**
	*This class represent the transfer view
  *@author Bjrn Sahlstrm
  */
class KBearTransferView : public KBearTreeView {
   Q_OBJECT

public:
	/**  */
	KBearTransferView(QWidget *parent=0, const char *name=0 );
	/**  */
	~KBearTransferView();
signals:
	void showMenu( KBearTransferViewItem* );
	protected slots: // Protected slots
	/**  */
	void slotItemRightPressed( KListView*, QListViewItem*, const QPoint& );
};

#endif
